"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InjectComponentsListToHtmlPlugin = void 0;
const InjectHtmlPlugin_1 = require("./InjectHtmlPlugin");
const webpack_config_1 = require("../componentsList/webpack.config");
const PLUGIN_NAME = 'InjectComponentsListToHtmlPlugin';
const INDEX = 'index.html';
const APP_JS = '[src="./build/dev/app.js"]';
class InjectComponentsListToHtmlPlugin extends InjectHtmlPlugin_1.InjectHtmlPlugin {
    apply(compiler) {
        compiler.hooks.emit.tapPromise(PLUGIN_NAME, async (compilation) => {
            await this.ensureIndexAssetExists(compilation);
            const $ = this.getParsedHtml(compilation, INDEX);
            this.appendComponentsLibraryToHtml(compilation, $);
            this.updateAsset(compilation, INDEX, $.html({ normalizeWhitespace: true }));
        });
    }
    async ensureIndexAssetExists(compilation) {
        try {
            super.ensureAssetExists(compilation, INDEX);
        }
        catch (_a) {
            const errorMessage = `${PLUGIN_NAME}: Missing index.html.`;
            compilation.errors.push(errorMessage);
            throw new Error(errorMessage);
        }
    }
    appendComponentsLibraryToHtml(compilation, $) {
        const prependToElement = $(APP_JS);
        const scriptSource = `./${webpack_config_1.filename}`;
        if (!prependToElement) {
            const error = `${PLUGIN_NAME}: there is no app.js script in index.html`;
            compilation.errors.push(error);
            throw new Error(error);
        }
        $('body').find(`script[src="${scriptSource}"]`).remove();
        prependToElement.before(`<script src="${scriptSource}"></script>\n`);
    }
}
exports.InjectComponentsListToHtmlPlugin = InjectComponentsListToHtmlPlugin;
//# sourceMappingURL=InjectComponentsListToHtmlPlugin.js.map